require 'spec_helper'

describe GtinValidator do

  context "has a valid value" do
    let(:klass) do
      Class.new do
        include ActiveModel::Validations
        attr_accessor :code, :name
        validates :code, gtin: true
      end
    end

    subject { klass.new }

    it { should allow_value("73513537").for(:code) }
    it { should allow_value("4006381333931").for(:code) }
    it { should allow_value("9780471117094").for(:code) }
    it { should allow_value("73 51353 7").for(:code) }
    it { should allow_value("4 006381 33393 1").for(:code) }
    it { should allow_value("97 804711 17094").for(:code) }

    it { should_not allow_value('').for(:code) }
    it { should_not allow_value(' ').for(:code) }
    it { should_not allow_value(nil).for(:code) }
    it { should_not allow_value("73513536").for(:code) }
    it { should_not allow_value("97804711170941").for(:code) }
    it { should_not allow_value("73 51353 6").for(:code) }
    it { should_not allow_value("97 804711 17094 1").for(:code) }
    it { should_not allow_value("! \#$%\`|").for(:code) }
    it { should_not allow_value("<>@[]\`|").for(:code) }

    it { should ensure_valid_gtin_format_of(:code) }
    it { should_not ensure_valid_gtin_format_of(:name) }
  end

  context "with :strict option has a valid value" do
    let(:klass) do
      Class.new do
        include ActiveModel::Validations
        attr_accessor :code, :name
        validates :code, gtin: { strict: true }
      end
    end

    subject { klass.new }

    it { should allow_value("73513537").for(:code) }
    it { should allow_value("4006381333931").for(:code) }
    it { should allow_value("9780471117094").for(:code) }

    it { should_not allow_value('').for(:code) }
    it { should_not allow_value(' ').for(:code) }
    it { should_not allow_value(nil).for(:code) }
    it { should_not allow_value("73513536").for(:code) }
    it { should_not allow_value("97804711170941").for(:code) }
    it { should_not allow_value("73 51353 6").for(:code) }
    it { should_not allow_value("73 51353 7").for(:code) }
    it { should_not allow_value("4 006381 33393 1").for(:code) }
    it { should_not allow_value("97 804711 17094 1").for(:code) }
    it { should_not allow_value("97 804711 17094").for(:code) }
    it { should_not allow_value("! \#$%\`|").for(:code) }
    it { should_not allow_value("<>@[]\`|").for(:code) }

    it { should ensure_valid_gtin_format_of(:code) }
    it { should_not ensure_valid_gtin_format_of(:name) }
  end

  context "with format: :ean_8 and :strict options has a valid value" do
    let(:klass) do
      Class.new do
        include ActiveModel::Validations
        attr_accessor :code, :name
        validates :code, gtin: { format: :ean_8, strict: true }
      end
    end

    subject { klass.new }

    it { should allow_value("73513537").for(:code) }

    it { should_not allow_value('').for(:code) }
    it { should_not allow_value(' ').for(:code) }
    it { should_not allow_value(nil).for(:code) }
    it { should_not allow_value("73513536").for(:code) }
    it { should_not allow_value("4006381333931").for(:code) }
    it { should_not allow_value("9780471117094").for(:code) }
    it { should_not allow_value("97804711170941").for(:code) }
    it { should_not allow_value("73 51353 6").for(:code) }
    it { should_not allow_value("73 51353 7").for(:code) }
    it { should_not allow_value("4 006381 33393 1").for(:code) }
    it { should_not allow_value("97 804711 17094 1").for(:code) }
    it { should_not allow_value("97 804711 17094").for(:code) }
    it { should_not allow_value("! \#$%\`|").for(:code) }
    it { should_not allow_value("<>@[]\`|").for(:code) }

    it { should ensure_valid_gtin_format_of(:code) }
    it { should_not ensure_valid_gtin_format_of(:name) }
  end

end